/*
 * Copyright 2002 Sun Microsystems, Inc. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 * 
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * 
 * - Redistribution in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials
 *   provided with the distribution.
 * 
 * Neither the name of Sun Microsystems, Inc. or the names of
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 * 
 * This software is provided "AS IS," without a warranty of any
 * kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND
 * WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY
 * EXCLUDED. SUN AND ITS LICENSORS SHALL NOT BE LIABLE FOR ANY
 * DAMAGES OR LIABILITIES SUFFERED BY LICENSEE AS A RESULT OF OR
 * RELATING TO USE, MODIFICATION OR DISTRIBUTION OF THIS SOFTWARE OR
 * ITS DERIVATIVES. IN NO EVENT WILL SUN OR ITS LICENSORS BE LIABLE
 * FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT,
 * SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER
 * CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF
 * THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF SUN HAS
 * BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * 
 * You acknowledge that this software is not designed, licensed or
 * intended for use in the design, construction, operation or
 * maintenance of any nuclear facility.
 */
package beantest;

import javax.swing.Action;
import javax.swing.ButtonGroup;
import javax.swing.JMenu;
import javax.swing.JMenuItem;

import com.sun.java.swing.action.StateChangeAction;

import com.sun.java.swing.ui.CommonMenuBar;

import beantest.action.*;

import beantest.util.StatusBar;

/**
 * Specific menubar for the BeanBuilder appliction.
 *
 * @version  %I% %G%
 * @author  Mark Davidson
 */
public class BeanMainMenu extends CommonMenuBar {
    
    public BeanMainMenu()   {
	super(BeantestActionManager.getInstance());
    }

    /** 
     * Overloaded method to configure the menu.
     */
    protected void configureMenu()  {
        add(createFileMenu("File", 'f'));
        add(createViewMenu("View", 'v'));
        add(createIconsMenu("Icons", 'i'));
        add(createHelpMenu("Help", 'h'));
    }

    /** 
     * Create the file menu
     */
    private JMenu createFileMenu(String name, char mnemonic)  {
        JMenu menu = createMenu(name, mnemonic);

        // Add commands
        addMenuItem(menu, manager.getAction(NewAction.VALUE_NAME));
        addMenuItem(menu, manager.getAction(OpenAction.VALUE_NAME));
        addMenuItem(menu, manager.getAction(SaveAction.VALUE_NAME));
        addMenuItem(menu, manager.getAction(SaveAsAction.VALUE_NAME));
        menu.addSeparator();
        addMenuItem(menu, manager.getAction(LoadAction.VALUE_NAME));
        addMenuItem(menu, manager.getAction(PaletteAction.VALUE_NAME));
        menu.addSeparator();
        addMenuItem(menu, manager.getAction(ExitAction.VALUE_NAME));
        
        return menu;
    }

    /** 
     * Create the view menu
     */
    private JMenu createViewMenu(String name, char mnemonic)  {
        JMenu menu = createMenu(name, mnemonic);

        // Add commands (on by default)
        addCheckBoxMenuItem(menu, manager.getStateChangeAction(DesignAction.VALUE_NAME), 
			    true);
        return menu;
    }
    
    /** 
     * Create the icons menu
     */
    private JMenu createIconsMenu(String name, char mnemonic)  {
        JMenu menu = createMenu(name, mnemonic);

        ButtonGroup group = new ButtonGroup();

        // Add Radio buttons. The first item is the default
        addRadioButtonMenuItem(menu, group, 
			       manager.getAction(IconAction.VALUE_NAME_ICON_32C), 
			       true);
        addRadioButtonMenuItem(menu, group, 
			       manager.getAction(IconAction.VALUE_NAME_ICON_16C));
        addRadioButtonMenuItem(menu, group, 
			       manager.getAction(IconAction.VALUE_NAME_ICON_32M));
        addRadioButtonMenuItem(menu, group, 
			       manager.getAction(IconAction.VALUE_NAME_ICON_16M));
        
        return menu;
    }
    
    /** 
     * Create the help menu
     */
    private JMenu createHelpMenu(String name, char mnemonic)  {
        JMenu menu = createMenu(name, mnemonic);
        
        addMenuItem(menu, manager.getAction(HelpAction.VALUE_NAME));
        menu.addSeparator();
        addMenuItem(menu, manager.getAction(AboutAction.VALUE_NAME));
        
        return menu;
    }

    /** 
     * Should implement this for configuration
     */
    protected void configureMenuItem(JMenuItem menuItem, Action action) {
	super.configureMenuItem(menuItem, action);

        // The status bar listens to mouse events 
        menuItem.addMouseListener(StatusBar.getInstance());
    }

}

