/*
 * Copyright 2002 Sun Microsystems, Inc. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 * 
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * 
 * - Redistribution in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials
 *   provided with the distribution.
 * 
 * Neither the name of Sun Microsystems, Inc. or the names of
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 * 
 * This software is provided "AS IS," without a warranty of any
 * kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND
 * WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY
 * EXCLUDED. SUN AND ITS LICENSORS SHALL NOT BE LIABLE FOR ANY
 * DAMAGES OR LIABILITIES SUFFERED BY LICENSEE AS A RESULT OF OR
 * RELATING TO USE, MODIFICATION OR DISTRIBUTION OF THIS SOFTWARE OR
 * ITS DERIVATIVES. IN NO EVENT WILL SUN OR ITS LICENSORS BE LIABLE
 * FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT,
 * SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER
 * CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF
 * THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF SUN HAS
 * BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * 
 * You acknowledge that this software is not designed, licensed or
 * intended for use in the design, construction, operation or
 * maintenance of any nuclear facility.
 */

package beantest.action;

import javax.swing.AbstractButton;
import javax.swing.Action;

import com.sun.java.swing.action.ActionManager;

/**
 * Provides the specific implementation of the ActionManager.
 *
 * @version  %I% %G%
 * @author  Mark Davidson
 */
public class BeantestActionManager extends ActionManager {

    /**
     * Return the shared instance of the ActionManager.
     */
    public static ActionManager getInstance() {
	if (manager == null) {
	    manager = new BeantestActionManager();
	}
	return manager;
    }

    /** 
     * Adds commands to the action manager
     * Any new functionality should be added here.
     */
    protected void addActions()  {
	
	// Main menu and toolbar actions
        addAction(NewAction.VALUE_NAME, new NewAction());
        addAction(SaveAction.VALUE_NAME, new SaveAction());
        addAction(SaveAsAction.VALUE_NAME, new SaveAsAction());
        addAction(OpenAction.VALUE_NAME, new OpenAction());
        addAction(LoadAction.VALUE_NAME, new LoadAction());
        addAction(PaletteAction.VALUE_NAME, new PaletteAction());
        addAction(ExitAction.VALUE_NAME, new ExitAction());

        addAction(IconAction.VALUE_NAME_ICON_32C, 
		  new IconAction(IconAction.VALUE_NAME_ICON_32C));
        addAction(IconAction.VALUE_NAME_ICON_16C, 
		  new IconAction(IconAction.VALUE_NAME_ICON_16C));
        addAction(IconAction.VALUE_NAME_ICON_32M, 
		  new IconAction(IconAction.VALUE_NAME_ICON_32M));
        addAction(IconAction.VALUE_NAME_ICON_16M, 
		  new IconAction(IconAction.VALUE_NAME_ICON_16M));

        addAction(HelpAction.VALUE_NAME, new HelpAction());
        addAction(AboutAction.VALUE_NAME, new AboutAction());

	// Property panel actions

        addAction(UpAction.VALUE_NAME, new UpAction());
        addAction(DownAction.VALUE_NAME, new DownAction());
        addAction(AddAction.VALUE_NAME, new AddAction());
        addAction(CustomizerAction.VALUE_NAME, new CustomizerAction());

        // Control panel actions
        addAction(DesignAction.VALUE_NAME, new DesignAction());

    }

}
