/*
 * Copyright 2002 Sun Microsystems, Inc. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 * 
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * 
 * - Redistribution in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials
 *   provided with the distribution.
 * 
 * Neither the name of Sun Microsystems, Inc. or the names of
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 * 
 * This software is provided "AS IS," without a warranty of any
 * kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND
 * WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY
 * EXCLUDED. SUN AND ITS LICENSORS SHALL NOT BE LIABLE FOR ANY
 * DAMAGES OR LIABILITIES SUFFERED BY LICENSEE AS A RESULT OF OR
 * RELATING TO USE, MODIFICATION OR DISTRIBUTION OF THIS SOFTWARE OR
 * ITS DERIVATIVES. IN NO EVENT WILL SUN OR ITS LICENSORS BE LIABLE
 * FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT,
 * SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER
 * CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF
 * THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF SUN HAS
 * BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 * 
 * You acknowledge that this software is not designed, licensed or
 * intended for use in the design, construction, operation or
 * maintenance of any nuclear facility.
 */
package com.sun.java.swing.ui;

import java.awt.Dimension;
import java.awt.Insets;

import javax.swing.AbstractButton;
import javax.swing.Action;
import javax.swing.Icon;
import javax.swing.JButton;
import javax.swing.JToggleButton;
import javax.swing.JToolBar;

import com.sun.java.swing.action.ActionManager;
import com.sun.java.swing.action.StateChangeAction;

/**
 * A configurable toolbar which uses the action manager.
 *
 * @version  %I% %G%
 * @author  Mark Davidson
 */
public abstract class CommonToolBar extends JToolBar {
        
    protected ActionManager manager;

    private Dimension buttonSize;
    private Insets buttonInsets;

    /**
     * ctor
     *
     * @param manager The action manager which manages interactions.
     */
    protected CommonToolBar(ActionManager manager) {
	this.manager = manager;
        buttonSize = new Dimension(CommonUI.buttconPrefSize);
        buttonInsets = new Insets(0,0,0,0);
        
        addButtons();
    }
    
    /** 
     * Adds the buttons to the toolbar. Subclasses must implement this method
     */
    protected abstract void addButtons();

    /** 
     * Adds and configures the button based on the action. 
     */
    protected void addButton(Action action)  {
        JButton button = add(action);

        configureButton(button, action);
    }
    
    /** 
     * Adds and configures a toggle button.
     * @param a an abstraction of a toggle action.
     */
    protected void addToggleButton(StateChangeAction a)  {
        JToggleButton button = new JToggleButton(a);
        button.addItemListener(a);
        button.setSelected(a.isSelected());
        
        add(button);

        configureToggleButton(button, a);
    }

    /** 
     * override for custom configuration
     */
    protected void configureToggleButton(JToggleButton button, Action action) {
	configureButton(button, action);
	
	// The PropertyChangeListener that gets added
	// to the Action doesn't know how to handle the "selected" property change
	// in the meantime, the corect thing to do is to add another PropertyChangeListener
	// to the StateChangeAction until this is fixed.
	action.addPropertyChangeListener(new ToggleActionPropertyChangeListener(button));
    }


    /** 
     * Helper method to configure the button 
     */
    protected void configureButton(AbstractButton button, Action action)  {
        button.setToolTipText((String)action.getValue(Action.NAME));

        // Don't show the text under the toolbar buttons.
        button.setText("");
    }
}
